# RaminDownloader

##A Python library for downloading videos from aparat.com

## Installation


```python
#pip install RaminDownloader
```

## Usage

```python
# import main

# Enter the url: https://www.aparat.com/example


# Enter the quality: 120, 240, 360, 480, 720, 1080


```
